//
//  NSDecimalNumber+BUYAdditions.h
//  Mobile Buy SDK
//
//  Created by Shopify.
//  Copyright (c) 2015 Shopify Inc. All rights reserved.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
//

@import Foundation;

@interface NSDecimalNumber (BUYAdditions)

/**
 *  Converts a string into an NSDecimalNumber or zero (if nil or not a number)
 *
 *  @param string The string to convert
 *
 *  @return NSDecimalNumber from a string
 */
+ (NSDecimalNumber*)buy_decimalNumberOrZeroWithString:(NSString*)string;

/**
 *  Converts a JSON value to an NSDecimalNumber
 *
 *  @param valueFromJSON The value to convert
 *
 *  @return NSDecimalNumber from a JSON string
 */
+ (NSDecimalNumber*)buy_decimalNumberFromJSON:(id)valueFromJSON;

/**
 *  Converts a decimal number to a negative value
 *
 *  @return The same decimal number but as a negative
 */
- (NSDecimalNumber*)buy_decimalNumberAsNegative;

@end
